/*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
'This program executes a 6 point current and voltage list.  
' It also specifies 6 different dwell times.
'~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/

using System;
using KepcoDCPwr.Interop;

namespace ListExample
{
	/// <summary>
	/// Summary description for Class1.
	/// </summary>
	class Class1
	{
		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main(string[] args)
		{
			// Create driver instance.
			KepcoDCPwr KLPdriver;
			KepcoDCPwr.Interop.IOutput outputPtr;
			KepcoDCPwr.Interop.IList  listPtr;
			KLPdriver = new KepcoDCPwrClass();

			 

			try
			{

				// Initialize driver 
				KLPdriver.Initialize("GPIB0::6::INSTR",
					true,
					true,
					"Cache=true,InterchangeCheck=false,QueryInstrStatus=true,Simulate=false");//Optional ivi options

				System.Console.WriteLine("Done.\n");

				// get references to the needed interfaces
				outputPtr = KLPdriver.Outputs.get_Item(driver.Outputs)	;
				listPtr = KLPdriver.List.get_Item(driver.Lists);

				//create arrays for the ListPoints method
				double[] voltList = new double [6];
				double[] currList = new double [6];
				double[] dwellTime = new double [6];

				voltList[0] = 10;
				voltList[1] = 20;
				voltList[2] = 30;
				voltList[3] = 40;
				voltList[4] = 50;
				voltList[5] = 60;

				currList[0] = 2;  // select max current for each step 
				currList[1] = 2;   
				currList[2] = 2;
				currList[3] = 2;
				currList[4] = 2;
				currList[5] = 2;

				dwellTime[0] = 1;
				dwellTime[1] = 2;
				dwellTime[2] = 3;
				dwellTime[3] = 4;
				dwellTime[4] = 5;
				dwellTime[5] = 0.01;

				//' call ListPoints to set the list values and set the voltage and current modes to LIST
				listPtr.ListPoints(ref voltList, ref currList, ref dwellTime);

				// enable the output
				outputPtr.Enabled = true;

				// Set the number of executions.
				listPtr.count = 2;

				// initiate the list in the output system
				outputPtr.listInitiate();


				KLPdriver.Systems.WaitForOperationComplete(10000);

				//Read insturment errors
				ReadInstrumentError(driver);

				//' Close driver if initialized.
				if (KLPdriver.Initialized == true ) KLPdriver.Close();

				Console.WriteLine();
				Console.Write("Press Enter to Exit ");
				Console.ReadLine();
			}
			catch (Exception e)
			{
				Console.WriteLine();
				Console.WriteLine("Exception Error:");
				Console.WriteLine("  " + e.Message );

				KLPdriver.Close();

				Console.WriteLine();
				Console.Write("Press Enter to Exit ");
				Console.ReadLine();
			}
		}

	}
}
