#include "KpDCPwr.h"
#include <ansi_c.h>
#include <cvirte.h>		
#include <userint.h>
#include <visatype.h>
#include "KpDCPwrErrorHandler.h"
#include "KpDCPwrExample.h"

static int panelHandle;
static ViSession vi;

int main (int argc, char *argv[])
{
	if (InitCVIRTE (0, argv, 0) == 0)
		return -1;	/* out of memory */
	if ((panelHandle = LoadPanel (0, "KpDCPwrExample.uir", PANEL)) < 0)
		return -1;
	DisplayPanel (panelHandle);
	RunUserInterface ();
	DiscardPanel (panelHandle);
	return 0;
}

int CVICALLBACK Initialize (int panel, int control, int event,
		void *callbackData, int eventData1, int eventData2)
{
   	ViChar resourceName[256];
	ViChar initOptions[256];
	ViStatus  error = VI_SUCCESS;
	int simulate;
	
	switch (event)
	{
		case EVENT_COMMIT:
			// Disable the Initialize button to provide visual feedback that initialization is in progress
			SetCtrlAttribute(panelHandle, PANEL_INITIALIZE_BUTTON, ATTR_DIMMED, 1);
			
			ProcessDrawEvents();
			
			// Get the resource descriptor
			GetCtrlVal(panelHandle, PANEL_RESOURCE_DESCRIPTOR, resourceName);
			
			// Determine if we're simulating
			GetCtrlVal(panelHandle, PANEL_SIMULATE_CHECKBOX, &simulate);
			
			sprintf(initOptions, "QueryInstrStatus=1, Simulate=%d", simulate);
			
			// Initialize the driver
			checkErr(KpDCPwr_InitWithOptions(resourceName, VI_TRUE, VI_TRUE, initOptions, &vi));
			
			// Enable the password state
			checkErr(KpDCPwr_EnablePasswordState(vi, "7533"));
			
			break;
	}
	
Error:
   
   if(error < VI_SUCCESS)
      ErrorHandler(vi);

	// Renable the Initialize button
	SetCtrlAttribute(panelHandle, PANEL_INITIALIZE_BUTTON, ATTR_DIMMED, 0);

	return 0;
}

int CVICALLBACK Configure (int panel, int control, int event,
		void *callbackData, int eventData1, int eventData2)
{
	ViStatus  error = VI_SUCCESS;
	double voltageLimit;
	double currentLimit;
	
	switch (event)
	{
		case EVENT_COMMIT:

			// Get the desired voltage limit from the UI
			GetCtrlVal(panelHandle, PANEL_VOLTAGE_LIMIT, &voltageLimit);
			
			// Set the voltage limit
			checkErr(KpDCPwr_SetAttributeViReal64(vi, VI_NULL, KPDCPWR_ATTR_POSITIVE_VOLTAGE_RATED_LIMIT, voltageLimit));
				
			// Get the desired current limit from the UI
			GetCtrlVal(panelHandle, PANEL_CURRENT_LIMIT, &currentLimit);
			
			// Set the current limit
			checkErr(KpDCPwr_SetAttributeViReal64(vi, VI_NULL, KPDCPWR_ATTR_POSITIVE_CURRENT_RATED_LIMIT, currentLimit));
				
			break;
	}
	
Error:
   
   if(error < VI_SUCCESS)
      ErrorHandler(vi);

	// Renable the Initialize button
	SetCtrlAttribute(panelHandle, PANEL_INITIALIZE_BUTTON, ATTR_DIMMED, 0);

	return 0;
}
